@@ -3,13 +3,11 @@ package DateTime::Helpers;
 use strict;
 use warnings;
 
-our $VERSION = '0.53';
+our $VERSION = '0.54';
 
 use Scalar::Util ();
 
-
-sub can
-{
+sub can {
     my $object = shift;
     my $method = shift;
 
@@ -17,8 +15,7 @@ sub can
     return $object->can($method);
 }
 
-sub isa
-{
+sub isa {
     my $object = shift;
     my $method = shift;
 
@@ -26,7 +23,6 @@ sub isa
     return $object->isa($method);
 }
 
-
 1;
 
 __END__
@@ -44,7 +40,7 @@ stole all the code from.
 
 =head1 COPYRIGHT
 
-Copyright (c) 2003-2009 David Rolsky.  All rights reserved.  This
+Copyright (c) 2003-2010 David Rolsky.  All rights reserved.  This
 program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
 
